==> ath1121501_1.8.2.tar.gz: ath1121501/man/ath1121501PMID2PROBE.Rd <==
\name{ath1121501PMID2PROBE}
\alias{ath1121501PMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  ath1121501PMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/Gene_Anatomy/ATH_Anatomy.20040209.txt}
Built: N/A 
  
  Package built Tue May 17 18:45:34 2005
}

\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}

==> ath1121501_1.10.0.tar.gz: ath1121501/man/ath1121501PMID2PROBE.Rd <==
\name{ath1121501PMID2PROBE}
\alias{ath1121501PMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  ath1121501PMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/TAIR_Ontology/ATH_anatomy.20050119.txt}
Built: N/A 
  
  Package built Tue Oct  4 19:05:27 2005
}

\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}
